==> Xbae-4.7.3.tar.gz: Xbae-4.7.3/include/Xbae/Actions.h <==
/*
 * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
 * Copyright(c) 1995-99 Andrew Lister
 *
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 * $Id: Actions.h,v 1.3 2000/02/29 19:29:09 danny Exp $
 */

/*
 * Actions.h created by Andrew Lister (6 August, 1995)
 */

#ifndef _Xbae_Actions_h
#define _Xbae_Actions_h

#include <Xbae/Macros.h>

/*
 * Actions
 */

#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

void xbaeEditCellACT(Widget, XEvent *, String *, Cardinal *);
void xbaeCancelEditACT(Widget, XEvent *, String *, Cardinal *);
void xbaeCommitEditACT(Widget, XEvent *, String *, Cardinal *);
void xbaeSelectCellACT(Widget, XEvent *, String *, Cardinal *);
void xbaeDefaultActionACT(Widget, XEvent *, String *, Cardinal *);
void xbaeResizeColumnsACT(Widget, XEvent *, String *, Cardinal *);
void xbaeTraverseNextACT(Widget, XEvent *, String *, Cardinal *);
void xbaeTraversePrevACT(Widget, XEvent *, String *, Cardinal *);
void xbaeProcessDragACT(Widget, XEvent *, String *, Cardinal *);
void xbaeHandleClick(Widget, XtPointer, XEvent *, Boolean *);
void xbaeHandleMotionACT(Widget, XEvent *, String *, Cardinal *);
void xbaePageDownACT(Widget, XEvent *, String *, Cardinal *);
void xbaePageUpACT(Widget, XEvent *, String *, Cardinal *);

#if defined(__cplusplus) || defined(c_plusplus)
}
#endif

#endif

==> Xbae-4.50.91.tar.gz: Xbae-4.50.91/include/Xbae/Actions.h <==
/*
 * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
 * Copyright(c) 1995-99 Andrew Lister
 * Copyright (c) 1999-2002 by the LessTif Developers.
 *
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 * $Id: Actions.h,v 1.8 2002/03/08 16:12:23 amai Exp $
 */

/*
 * Actions.h created by Andrew Lister (6 August, 1995)
 */

#ifndef _Xbae_Actions_h
#define _Xbae_Actions_h

#include <Xbae/Macros.h>

/*
 * Actions
 */

#ifdef __cplusplus
extern "C" {
#endif

void xbaeEditCellACT(Widget, XEvent *, String *, Cardinal *);
void xbaeCancelEditACT(Widget, XEvent *, String *, Cardinal *);
void xbaeCommitEditACT(Widget, XEvent *, String *, Cardinal *);
void xbaeSelectCellACT(Widget, XEvent *, String *, Cardinal *);
void xbaeDefaultActionACT(Widget, XEvent *, String *, Cardinal *);
void xbaeResizeColumnsACT(Widget, XEvent *, String *, Cardinal *);
void xbaeTraverseNextACT(Widget, XEvent *, String *, Cardinal *);
void xbaeTraversePrevACT(Widget, XEvent *, String *, Cardinal *);
void xbaeProcessDragACT(Widget, XEvent *, String *, Cardinal *);
void xbaeHandleClick(Widget, XtPointer, XEvent *, Boolean *);
void xbaeHandleMotionACT(Widget, XEvent *, String *, Cardinal *);
void xbaePageDownACT(Widget, XEvent *, String *, Cardinal *);
void xbaePageUpACT(Widget, XEvent *, String *, Cardinal *);

#ifdef __cplusplus
}
#endif

#endif /* _Xbae_Actions_h */
